==> mule-standalone-3.0.0.tar.gz: org/mule/transport/email/config/AbstractEmailNamespaceHandlerTestCase.java <==
/*
 * $Id: AbstractEmailNamespaceHandlerTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
 * --------------------------------------------------------------------------------------
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 *
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.transport.email.config;

import org.mule.api.MuleException;
import org.mule.api.endpoint.ImmutableEndpoint;
import org.mule.tck.FunctionalTestCase;

public abstract class AbstractEmailNamespaceHandlerTestCase extends FunctionalTestCase
{
    protected void testInboundEndpoint(String name, String protocolName) throws MuleException
    {
        ImmutableEndpoint endpoint =
            muleContext.getRegistry().lookupEndpointFactory().getInboundEndpoint(name);
        testEndpoint(endpoint, protocolName);
    }

    protected void testOutboundEndpoint(String name, String protocolName) throws MuleException
    {
        ImmutableEndpoint endpoint =
            muleContext.getRegistry().lookupEndpointFactory().getOutboundEndpoint(name);
        testEndpoint(endpoint, protocolName);
    }

    private void testEndpoint(ImmutableEndpoint endpoint, String protocolName)
    {
        assertNotNull(endpoint);
        String address = endpoint.getEndpointURI().getAddress();
        assertNotNull(address);
        assertEquals("bob@localhost:123", address);
        String password = endpoint.getEndpointURI().getPassword();
        assertNotNull(password);
        assertEquals("secret", password);
        String protocol = endpoint.getProtocol();
        assertNotNull(protocol);
        assertEquals(protocolName, protocol);
    }
}

==> mule-standalone-3.3.0.tar.gz: org/mule/transport/email/config/AbstractEmailNamespaceHandlerTestCase.java <==
/*
 * $Id: AbstractEmailNamespaceHandlerTestCase.java 22431 2011-07-18 07:40:35Z dirk.olmes $
 * --------------------------------------------------------------------------------------
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 *
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.transport.email.config;

import org.mule.api.MuleException;
import org.mule.api.endpoint.ImmutableEndpoint;
import org.mule.tck.junit4.FunctionalTestCase;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;

public abstract class AbstractEmailNamespaceHandlerTestCase extends FunctionalTestCase
{

    protected void testInboundEndpoint(String name, String protocolName) throws MuleException
    {
        ImmutableEndpoint endpoint =
            muleContext.getEndpointFactory().getInboundEndpoint(name);
        testEndpoint(endpoint, protocolName);
    }

    protected void testOutboundEndpoint(String name, String protocolName) throws MuleException
    {
        ImmutableEndpoint endpoint =
            muleContext.getEndpointFactory().getOutboundEndpoint(name);
        testEndpoint(endpoint, protocolName);
    }

    private void testEndpoint(ImmutableEndpoint endpoint, String protocolName)
    {
        assertNotNull(endpoint);
        String address = endpoint.getEndpointURI().getAddress();
        assertNotNull(address);
        assertEquals("bob@localhost:123", address);
        String password = endpoint.getEndpointURI().getPassword();
        assertNotNull(password);
        assertEquals("secret", password);
        String protocol = endpoint.getProtocol();
        assertNotNull(protocol);
        assertEquals(protocolName, protocol);
    }
}
